# Alluka

A type based dependency injection framework for Python 3.9+.

# Usage

For how to get started with this library, see the [documentation](https://alluka.cursed.solutions/usage).

# Installation

You can install Alluka from PyPI using the following command in any Python 3.9 or above environment.

```
python -m pip install -U alluka
```

# Contributing

Before contributing you should read through the
[contributing guidelines](https://github.com/FasterSpeeding/Alluka/blob/master/CONTRIBUTING.md) and
the [code of conduct](https://github.com/FasterSpeeding/Alluka/blob/master/CODE_OF_CONDUCT.md).
